require "global";
require "local";
require "Nz_wpe";
require "ExtendNZ";
--正在攻击"00FF00","5|5|00FF00,10|2|00FF00,18|2|00FF00,21|-3|00FF00,22|-2|00FF00,24|-2|00FF00,27|0|00FF00,36|-2|00FF00,42|-3|00FF00,41|0|00FF00,43|4|00FF00,45|6|00FF00,46|7|00FF00,49|4|00FF00,53|7|00FF00,57|7|00FF00,57|4|00FF00,58|2|00FF00,57|-1|00FF00,53|-3|00FF00"
function checkgongji()
	intW, intH = GetWindowRect(); --获取窗体的高和宽
	intX = 0;
	intY = 0;
	intMaxX = intW;
	intMaxY = intH;
	intXC = math.random(intW/4,intW/4*3);
	intYC = math.random(intH/3,intH/3*2);
	strFirstClr = "DCE7A1";
	strParamter = "-61|7|FFFFFF,-61|-3|FFFFFF,-63|-3|FFFFFF,-71|0|FFFFFF,-74|1|FFFFFF,-76|-3|FFFFFF,-79|-3|FFFFFF,-83|-1|FFFFFF,-83|7|FFFFFF,-69|7|FFFFFF";
	intResult, intX, intY  = api_findMultiColor(intX, intY, intMaxX, intMaxY, strFirstClr, strParamter);
--	WriteLog( 'X3:', intX, 'Y:', intY, 'Result:', intResult );
	if intResult == 1 then
		return	true;
	else
		sendMouseClick(intXC , intYC ); --发送点击事件
		return	false;
	end
end
--api_StopApp();




--while   api_checkThread(87)  do
--strData4 ='E6 D0 D0 D0 A5 D0 58 88 08 CD D0 E3 E6 E0 E0 E0 E1 E1 E3 EA E1 E7 E6 E0 EA E6 E2 E4 EA E3 E6 E0 E0 E0 E1 E0 E7 EA E1 E6 E3 E2 EA E4 E8 E1 EA E1 E6 E3 E2 EA E5 E6 E0 EA E2 E3 ';
--api_sendData_NZ(strData4);
--api_LuaSleep(50);
--strData2 ='E6 D0 D0 D0 A5 D0 58 88 08 CD D0 E3 E6 E0 E0 E0 E1 E1 E3 EA E1 E7 E6 E0 EA E6 E2 E4 EA E3 E6 E0 E0 E0 E1 E0 E7 EA E1 E6 E3 E2 EA E4 E8 E1 EA E1 E6 E3 E2 EA E5 E6 E0 EA E2 E4 ';
--api_sendData_NZ(strData2);
--api_LuaSleep(10);
--strData13 ='FE D0 D0 D0 A5 D0 42 10 B5 AD D0 E2 E0 E0 E0 E0 E1 E5 EA E7 E5 E8 E2 EA E3 E1 E8 E4 EA FD E1 EA E7 E6 E4 E8 EA E3 E1 E8 E4 EA FD E1 EA FD E1 EA E1 E0';
--strData12 ='EA D0 D0 D0 A5 D0 C4 F0 87 D7 D0 E2 E0 E0 E0 E0 E1 E5 EA E8 E1 E5 E9 EA E2 E1 E9 E2 EA E1 E8 E7 E9 E0 E5 E9 E9 E4 E1 EA E8 E2 E2 E4 EA E2 E1 E6 E0 EA E8 E2 E2 E4 EA E2 E1 E6 E0 EA E1 E3';
--strData11 ='FE D0 D0 D0 A5 D0 42 10 B5 AD D0 E2 E0 E0 E0 E0 E1 E5 EA E7 E5 E8 E2 EA E3 E1 E8 E4 EA FD E1 EA E7 E6 E4 E8 EA E3 E1 E8 E4 EA FD E1 EA FD E1 EA E1 E3';
--strData1 ='E6 D0 D0 D0 A5 D0 58 88 08 CD D0 E3 E6 E0 E0 E0 E1 E1 E3 EA E1 E7 E6 E0 EA E6 E2 E4 EA E3 E6 E0 E0 E0 E1 E0 E7 EA E1 E6 E3 E2 EA E4 E8 E1 EA E1 E6 E3 E2 EA E5 E6 E0 EA E2 E6 ';
--api_sendData_NZ(strData12);
strData1 ='F1 D0 D0 D0 AB D0 95 C7 7E D2 D0 E3 E6 E0 E0 E0 E1 E1 E3 EA E1 E0 EA E4 E4 E0 E1 EA E6 E0 E1 EA E7 E7 E5 EA E7 E6 ';
strData11 ='FD D0 D0 D0 4E D1 07 4E 03 D8 D0 E2 E0 E0 E0 E0 E1 E5 EA E2 EA E1 E6 E1 E0 E6 E1 E2 E9 E4 E4 EA E2 E0 E8 EA E1 E0 EA 8F A4 BF BD B1 A0 E4 E4 E0 E0 ';
--strData1 ='E8 D0 D0 D0 A5 D0 2D 15 C1 D3 D0 E3 E6 E0 E0 E0 E1 E1 E3 EA E1 E5 E0 E4 EA E6 E2 E4 EA E1 E8 E7 E9 E0 E5 E8 E1 E5 E2 EA E1 E5 E0 E4 EA E4 E8 E0 EA E1 E5 E0 E4 EA E6 E5 E8 EA E2 E6 ';
--EA D0 D0 D0 A5 D0 FD A2 BA D3 D0 E2 E0 E0 E0 E0 E1 E5 EA E7 E5 E7 E9 EA E3 E1 E8 E4 EA E1 E8 E7 E9 E0 E4 E8 E6 E0 E1 EA E7 E6 E4 E8 EA E3 E1 E8 E4 EA E7 E6 E4 E8 EA E3 E1 E8 E4 EA E1 E3
--FE D0 D0 D0 A5 D0 E6 82 DE CA D0 E2 E0 E0 E0 E0 E1 E5 EA E5 E6 E6 E4 EA E2 E9 E9 E1 EA FD E1 EA E5 E6 E0 E0 EA E3 E0 E2 E4 EA FD E1 EA FD E1 EA E1 E3
--F9 D0 D0 D0 A2 D0 05 6E F6 D1 D0 E1 E3 E0 E0 E0 E0 E2 E4 EA E2 EA E2 EA E6 EA E7 E3 E9 E1 EA E3 E0 E8 E7 EA E7 E6 E4 E8 EA E3 E1 E8 E4

api_sendData_NZ(strData11);
api_LuaSleep(100);
api_sendData_NZ(strData1);
--	if  checkgongji() then
--		api_LuaSleep(10*1000);
--	end
	api_LuaSleep(50);
--end

--api_RunApp();
